# Bitspark: A Scalable Bloom Filter Implementation for Java

Bitspark is an implementation of a scalable Bloom Filter as proposed by a paper published by *Almeida* et al. in 2007. This project includes code to create benchmarks for various publicly available static Bloom filter implementations in Java and to evaluate whether the scalable version is performant enough with regard to runtime and false positive rates. The program will create a DataFrame holding the raw data points as measured during execution. The Bloom filter implementations currently used to create the benchmarks, called test subjects, are listed below. At the present, our implementation has a dependency on the *Murmur3* (128 bit) Hashing algorithm and a function to compute the base two logarithm as provided by Google's Guava library. This may change in the future if a more suitable algorithm can be incorporated into the Claymore library.

### Test Subjects

* Raven Computing (our base implementation)
* [Baqend](https://github.com/Baqend/Orestes-Bloomfilter) (static)
* [Google](https://github.com/google/guava) (static)
* [Sangupta](https://github.com/sangupta/bloomfilter) (static)
* [Gunlogson](https://github.com/MGunlogson/CuckooFilter4J) (cuckoo filter)

### Create Benchmarks

First, build the project with Maven:

> mvn package


Then run the executable *JAR* which is located in the build directory. Please note that it is recommended to have at least 10GB of free memory when performing benchmarks and to explicitly specify the allowed heap space when launching the program. From the project root directory you can run:

> java -Xmx10240M -jar build/benchmark-bloomfilter.jar


The program can be configured by passing command line arguments to it.
The following optional arguments can be used:

* -subject=<>
    * The name of the test subject to perform benchmarks for. The default is *all*
    
    
* -minimizedInitCap=[true|false]
    * A boolean flag indicating whether to enable minimization of the initial capacity of our filter. Setting this to *true* will effectively construct each of our Bloom filters with an initial capacity of only 1k elements, regardless of the set size. The other static test subjects will always be initialized with the actual set size. The default is *false*
    
    
* -fileFormat=[df|csv]
    * The file format to use when persisting the benchmark results. The default is *df* (DataFrame file)
    
    
* -debug=[true|false]
    * A boolean flag indicating whether to enable debug log statements. The default is *false*
    
    
* -useAnsiColors=[true|false]
    * A boolean flag indicating whether to use ANSI colors in the terminal output. If your terminal does not support colors then turn this off. The default is *true*



### Evaluate the Results

The program will create a DataFrame containing the results of the performed benchmark. Each row represents a distinct test lap. The columns have the following meaning:

* **Subject**: The name of the developer of the Bloom filter used in the lap
    
* **SetSize**: The size of the dataset used
    
* **SetType**: The type of the dataset used. Is either "Pattern" or "Random"
    
* **FPP-Max**: The maximum allowed false positive probability given to the underlying Bloom filter implementation
    
* **Time-AddMin**: The fastest runtime for all inserted elements (out of five)
    
* **Time-AddAvg**: The average runtime for all inserted elements (out of five)
    
* **Time-AddMax**: The slowest runtime for all inserted elements (out of five)
    
* **Time-ContMin**: The fastest runtime of membership queries (out of five)
    
* **Time-ContAvg**: The average runtime of membership queries (out of five)
    
* **Time-ContMax**: The fastest runtime of membership queries (out of five)
    
* **FP-Count**: The total amount of false positives out of a set containing 200000 definite negatives
    
* **FP-Rate**: The false positive rate out of a set containing 200000 definite negatives

### License

The code of this project is licensed under the Apache License Version 2 - see the LICENSE for details.

