/* 
 * Copyright (C) 2020 Raven Computing
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.raven.research.bitspark.subj;

import com.raven.research.bitspark.util.TestLap;

import orestes.bloomfilter.BloomFilter;
import orestes.bloomfilter.FilterBuilder;

/**
 * The TestSubject for handling the Bloom filter
 * implementation by Baqend.
 *
 */
public final class BaqendTestSubject implements TestSubject {
    
    private BloomFilter<String> bf;

    @Override
    public void initializeFor(final TestLap lap){
        this.bf = new FilterBuilder(
                lap.getDatasetSize(),
                lap.getAllowedFPP())
                .buildBloomFilter();
    }
    
    @Override
    public void add(final String element){
        this.bf.add(element);
    }

    @Override
    public boolean contains(final String element){
        return this.bf.contains(element);
    }

    @Override
    public String getDeveloperName(){
        return Subject.BAQEND.getName();
    }

}
