/* 
 * Copyright (C) 2020 Raven Computing
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.raven.research.bitspark.subj;

import java.nio.charset.StandardCharsets;

import com.github.mgunlogson.cuckoofilter4j.CuckooFilter;
import com.google.common.hash.Funnels;
import com.raven.research.bitspark.util.TestLap;

/**
 * The TestSubject for handling the Cuckoo filter
 * implementation by Gunlogson.
 *
 */
public class GunlogsonTestSubject implements TestSubject {
    
    private CuckooFilter<CharSequence> cf;

    @Override
    public void initializeFor(final TestLap lap){
        this.cf = new CuckooFilter.Builder<>(Funnels.stringFunnel(StandardCharsets.UTF_8),
                lap.getDatasetSize())
                .withFalsePositiveRate(lap.getAllowedFPP())
                .build();
    }

    @Override
    public void add(final String element){
        this.cf.put(element);
    }

    @Override
    public boolean contains(final String element){
        return this.cf.mightContain(element);
    }

    @Override
    public String getDeveloperName(){
        return Subject.GUNLOGSON.getName();
    }

}
