/* 
 * Copyright (C) 2020 Raven Computing
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.raven.research.bitspark.subj;

import com.raven.research.bitspark.struct.BloomFilter;
import com.raven.research.bitspark.util.TestLap;

/**
 * The TestSubject for handling the Bloom filter
 * implementation by Raven Computing.
 *
 */
public final class RavenTestSubject implements TestSubject {
    
    public static boolean useMinimizedInitCapacity;
    
    private BloomFilter bf;
    
    @Override
    public void initializeFor(final TestLap lap){
        this.bf = new BloomFilter(
                (useMinimizedInitCapacity ? TestLap.TESTED_SET_SIZES[0]: lap.getDatasetSize()),
                lap.getAllowedFPP());
        
    }

    @Override
    public void add(final String element){
        this.bf.add(element);
    }

    @Override
    public boolean contains(final String element){
        return this.bf.contains(element);
    }

    @Override
    public String getDeveloperName(){
        return Subject.RAVEN_COMPUTING.getName();
    }
    
}
