/* 
 * Copyright (C) 2020 Raven Computing
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.raven.research.bitspark.subj;

import com.raven.research.bitspark.util.TestLap;

/**
 * Interface to be implemented by concrete test subjects.
 *
 */
public interface TestSubject {
    
    /**
     * Called to let the test subject initialize its Bloom filter implementation
     * 
     * @param lap The TestLap to initialize the Bloom filter for
     */
    public void initializeFor(final TestLap lap);
    
    /**
     * Called when the specified element should get inserted by
     * the underlying Bloom filter implementation
     * 
     * @param element The element to be inserted
     */
    public void add(final String element);
    
    /**
     * Called when the specified element should get checked by
     * the underlying Bloom filter implementation for set membership
     * 
     * @param element The element to be checked for membership
     * @return True if the specified element is probably in the underlying
     *         Bloom filter implementation, false otherwise
     */
    public boolean contains(final String element);
    
    /**
     * Should return the name of the developer of the underlying
     * Bloom filter implementation 
     * 
     * @return The name of the developer
     */
    public String getDeveloperName();
    
}
