/* 
 * Copyright (C) 2020 Raven Computing
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.raven.research.bitspark.subj;

import java.util.ArrayList;
import java.util.List;

import com.raven.research.bitspark.util.Log;

/**
 * This class provides factory methods for creating TestSubject objects.
 *
 */
public final class TestSubjectProvider {
    
    public static TestSubject create(final Subject subject){
        if(subject == null){
            throw new IllegalArgumentException("Subject argument must not be null");
        }
        return instantiateTestSubject(subject);
    }
    
    public static List<TestSubject> createAll(){
        final List<TestSubject> list = new ArrayList<>();
        for(final Subject sbj : Subject.getAllSubjects()){
            list.add(instantiateTestSubject(sbj));
        }
        return list;
    }
    
    private static TestSubject instantiateTestSubject(final Subject subject){
        final Class<? extends TestSubject> subjectClass = subject.getImplementingClass();
        if(subjectClass == null){
            throw new IllegalStateException("No implementing class for test subject "
                    + subject.getName()
                    + " found");
        }
        Log.debug("Instantiating class for test subject " + subject.getName());
        try{
            return subjectClass.newInstance();
        }catch(InstantiationException ex){
            Log.error(ex);
        }catch(IllegalAccessException ex){
            Log.error(ex);
        }
        return null;
    }
    
}
