/* 
 * Copyright (C) 2020 Raven Computing
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.raven.research.bitspark.util;

import java.io.PrintStream;
import java.text.DecimalFormat;

import com.raven.common.util.Chronometer;

/**
 * A logger for printing log statements on either stdout or stderr.
 *
 */
public final class Log {
    
    public static boolean debug = false;
    
    public static boolean useAnsiColors = true;
    
    public static final String RED = "\033[0;31m";
    public static final String GREEN = "\033[0;32m";
    public static final String GREEN2 = "\033[1;32m";
    public static final String BLUE = "\033[1;34m";
    public static final String BLUE2 = "\033[0;36m";
    public static final String ORANGE = "\033[1;33m";
    public static final String NC = "\033[0m";
    
    private static final PrintStream STDOUT = System.out;
    private static final PrintStream STDERR = System.err;
    
    public static void info(){
        if(useAnsiColors){
            STDOUT.print("[");
            STDOUT.print(BLUE);
            STDOUT.print("INFO");
            STDOUT.print(NC);
            STDOUT.println("] ");
        }else{
            STDOUT.println("[INFO] ");
        }
    }
    
    public static void info(final String message){
        if(useAnsiColors){
            STDOUT.print("[");
            STDOUT.print(BLUE);
            STDOUT.print("INFO");
            STDOUT.print(NC);
            STDOUT.print("] ");
        }else{
            STDOUT.print("[INFO] ");
        }
        STDOUT.println(message);
    }
    
    public static void warn(final String message){
        if(useAnsiColors){
            STDOUT.print("[");
            STDOUT.print(ORANGE);
            STDOUT.print("WARN");
            STDOUT.print(NC);
            STDOUT.print("] ");
        }else{
            STDOUT.print("[WARN] ");
        }
        STDOUT.println(message);
    }
    
    public static void error(final String message){
        if(useAnsiColors){
            STDERR.print("[");
            STDERR.print(RED);
            STDERR.print("ERROR");
            STDERR.print(NC);
            STDERR.print("] ");
        }else{
            STDERR.print("[ERROR] ");
        }
        STDERR.println(message);
    }
    
    public static void error(final Throwable throwable){
        if(useAnsiColors){
            STDERR.print("[");
            STDERR.print(RED);
            STDERR.print("ERROR");
            STDERR.print(NC);
            STDERR.print("] ");
        }else{
            STDERR.print("[ERROR] ");
        }
        STDERR.print(throwable.getClass().getName());
        STDERR.print(": ");
        if(throwable.getMessage() != null){
            STDERR.println(throwable.getMessage());
        }
        throwable.printStackTrace(STDERR);
    }

    public static void debug(final String message){
        if(debug){
            if(useAnsiColors){
                STDOUT.print("[");
                STDOUT.print(BLUE);
                STDOUT.print("DEBUG");
                STDOUT.print(NC);
                STDOUT.print("] ");
            }else{
                STDOUT.print("[DEBUG] ");
            }
            STDOUT.println(message);
        }
    }
    
    public static void progress(final int lap, final int totalLaps){
        if(Log.useAnsiColors){
            Log.info("Running lap " + lap + "/" + totalLaps
                    + " (" + Log.BLUE2
                    + new DecimalFormat("0.0").format(((float)(lap-1) / (float)totalLaps)*100)
                    + "% complete" + Log.NC + ")");
            
        }else{
            Log.info("Running lap " + lap + "/" + totalLaps
                    + " ("
                    + new DecimalFormat("0.0").format(((float)(lap-1) / (float)totalLaps)*100)
                    + "% complete)");
            
        }
    }
    
    public static void summary(final int totalLaps, final Chronometer chrono){
        Log.info();
        if(useAnsiColors){
            Log.info(Log.GREEN2 + "Benchmark completed" + Log.NC);
        }else{
            Log.info("Benchmark completed");
        }
        Log.info();
        Log.info("All " + totalLaps + " laps took " + chrono.toString());
        Log.info();
    }
    
}
