/* 
 * Copyright (C) 2020 Raven Computing
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.raven.research.bitspark.util;

/**
 * Represents the result of runtime measurements.
 *
 */
public class RuntimeData {
    
    private long min;
    private long avg;
    private long max;
    
    
    public RuntimeData(final long min, final long avg, final long max){
        this.min = min;
        this.avg = avg;
        this.max = max;
    }
    
    public long getMinimun(){
        return this.min;
    }
    
    public long getAverage(){
        return this.avg;
    }
    
    public long getMaximum(){
        return this.max;
    }
    
    public static long selectMin(final long l1, final long l2){
        return ((l1 < l2) ? l1 : l2);
    }
    
    public static long selectMax(final long l1, final long l2){
        return ((l1 > l2) ? l1 : l2);
    }
    
    public static long averageFrom(final long sum, final int count){
        return (long)((double)sum / (double)count);
    }
    
    public static long defaultMinimum(){
        return Long.MAX_VALUE;
    }
    
    public static long defaultMaximum(){
        return Long.MIN_VALUE;
    }
    
}
