/* 
 * Copyright (C) 2020 Raven Computing
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.raven.research.bitspark.util;

import com.raven.common.struct.Row;
import com.raven.common.struct.RowItem;

/**
 * Models a test result holding the measured benchmark data points.
 *
 */
public class TestResult implements Row {
    
    public TestResult(final String subjectName){
        this.subjectName = subjectName;
    }
    
    @RowItem("Subject")
    private String subjectName;
    
    @RowItem("SetSize")
    private int datasetSize;
    
    @RowItem("SetType")
    private String datasetType;
    
    @RowItem("FPP-Max")
    private double allowedErrorRate;
    
    @RowItem("Time-AddMin")
    private long runtimeAddMin;
    
    @RowItem("Time-AddAvg")
    private long runtimeAddAvg;
    
    @RowItem("Time-AddMax")
    private long runtimeAddMax;
    
    @RowItem("Time-ContMin")
    private long runtimeContainsMin;
    
    @RowItem("Time-ContAvg")
    private long runtimeContainsAvg;
    
    @RowItem("Time-ContMax")
    private long runtimeContainsMax;
    
    @RowItem("FP-Count")
    private int errorCount;
    
    @RowItem("FP-Rate")
    private double errorRate;

    public String getSubjectName(){
        return this.subjectName;
    }

    public void setSubjectName(final String subjectName){
        this.subjectName = subjectName;
    }

    public int getDatasetSize(){
        return this.datasetSize;
    }

    public void setDatasetSize(final int datasetSize){
        this.datasetSize = datasetSize;
    }

    public String getDatasetType(){
        return this.datasetType;
    }

    public void setDatasetType(final String datasetType){
        this.datasetType = datasetType;
    }

    public double getAllowedErrorRate(){
        return this.allowedErrorRate;
    }

    public void setAllowedErrorRate(final double allowedErrorRate){
        this.allowedErrorRate = allowedErrorRate;
    }

    public long getRuntimeAddMin(){
        return this.runtimeAddMin;
    }

    public void setRuntimeAddMin(final long runtimeAddMin){
        this.runtimeAddMin = runtimeAddMin;
    }

    public long getRuntimeAddAvg(){
        return this.runtimeAddAvg;
    }

    public void setRuntimeAddAvg(final long runtimeAddAvg){
        this.runtimeAddAvg = runtimeAddAvg;
    }

    public long getRuntimeAddMax(){
        return this.runtimeAddMax;
    }

    public void setRuntimeAddMax(final long runtimeAddMax){
        this.runtimeAddMax = runtimeAddMax;
    }

    public long getRuntimeContainsMin(){
        return this.runtimeContainsMin;
    }

    public void setRuntimeContainsMin(final long runtimeContainsMin){
        this.runtimeContainsMin = runtimeContainsMin;
    }

    public long getRuntimeContainsAvg(){
        return this.runtimeContainsAvg;
    }

    public void setRuntimeContainsAvg(final long runtimeContainsAvg){
        this.runtimeContainsAvg = runtimeContainsAvg;
    }

    public long getRuntimeContainsMax(){
        return this.runtimeContainsMax;
    }

    public void setRuntimeContainsMax(final long runtimeContainsMax){
        this.runtimeContainsMax = runtimeContainsMax;
    }

    public int getErrorCount(){
        return this.errorCount;
    }

    public void setErrorCount(final int errorCount){
        this.errorCount = errorCount;
    }

    public double getErrorRate(){
        return this.errorRate;
    }

    public void setErrorRate(final double errorRate){
        this.errorRate = errorRate;
    }
}
